#
# spec file for package libgpg-error
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgpg-error
Version:        1.27
Release:        1.3
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            http://www.gnupg.org/
Source:         ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2
Source1:        ftp://ftp.gnupg.org/gcrypt/libgpg-error/%{name}-%{version}.tar.bz2.sig
# http://www.gnupg.org/signature_key.en.html
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package -n libgpg-error0
Summary:        Library That Defines Common Error Values for All GnuPG Components
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
#
Provides:       libgpg-error = %{version}
Obsoletes:      libgpg-error < %{version}

%description -n libgpg-error0
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon, and possibly more in the future.

%package devel
Summary:        Development package for libgpg-error
License:        GPL-2.0+ and LGPL-2.1+ and MIT
Group:          Development/Libraries/C and C++
#
Requires:       glibc-devel
Requires:       libgpg-error0 = %{version}
Requires(post): info
Requires(preun): info

%description devel
Files needed for software development using libgpg-error.

%prep
%setup -q -n libgpg-error-%{version}

%build
%configure \
	--disable-static \
	--with-pic
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm %{buildroot}%{_libdir}/libgpg-error.la
# Drop the lisp stuff, it depends on ASDF and CFFI
# which needs to be packaged first
rm -r %{buildroot}%{_datadir}/common-lisp
%find_lang %{name}

%check
make check %{?_smp_mflags}
%{buildroot}/%{_bindir}/gpg-error-config --libs | grep -q -v "\-lpthread"
%{buildroot}/%{_bindir}/gpg-error-config --mt --libs | grep -q "\-lpthread"

%post -n libgpg-error0 -p /sbin/ldconfig
%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/gpgrt.info.gz

%postun -n libgpg-error0 -p /sbin/ldconfig
%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gpgrt.info.gz

%files -n libgpg-error0 -f %{name}.lang
%defattr(-,root,root)
%{_libdir}/libgpg-error*.so.*

%files devel
%defattr(-,root,root)
%doc README NEWS ChangeLog COPYING.LIB COPYING AUTHORS ABOUT-NLS
%{_datadir}/aclocal/gpg-error.m4
%{_includedir}/*
%{_bindir}/*
%{_libdir}/libgpg-error*.so
%{_infodir}/gpgrt.info%{ext_info}
%{_mandir}/man1/gpg-error*.1%{ext_man}
%dir %{_datadir}/libgpg-error
%{_datadir}/libgpg-error/errorref.txt
%dir %{_datadir}/aclocal

%changelog
* Tue Mar  7 2017 astieger@suse.com
- update to 1.27:
  * Added a Base64 decoder.
  * Added support for the sh3 architecture.
  * Added header gpgrt.h as an alias for gpg-error.h.
  * Fixed macro GPGRT_GCC_VERSION.
  * Interface changes relative to the 1.26 release:
  gpgrt_b64state_t                 NEW type.
  gpgrt_b64dec_start               NEW.
  gpgrt_b64dec_proc                NEW.
  gpgrt_b64dec_finish              NEW.
  GPG_ERR_WRONG_NAME               NEW.
  gpgrt.h                          NEW header.
* Thu Dec 22 2016 astieger@suse.com
- update to 1.26:
  * New option --desc for gpg-error.
  * Interface changes relative to the 1.25 release:
  GPG_ERR_UNKNOWN_FLAG         NEW.
  GPG_ERR_INV_ORDER            NEW.
  GPG_ERR_ALREADY_FETCHED      NEW.
  GPG_ERR_TRY_LATER            NEW.
  GPG_ERR_SYSTEM_BUG           NEW.
  GPG_ERR_DNS_UNKNOWN          NEW.
  GPG_ERR_DNS_SECTION          NEW.
  GPG_ERR_DNS_ADDRESS          NEW.
  GPG_ERR_DNS_NO_QUERY         NEW.
  GPG_ERR_DNS_NO_ANSWER        NEW.
  GPG_ERR_DNS_CLOSED           NEW.
  GPG_ERR_DNS_VERIFY           NEW.
  GPG_ERR_DNS_TIMEOUT          NEW.
* Tue Nov 15 2016 astieger@suse.com
- update to 1.25:
  * New interface gpgrt_get_syscall_clamp to allow libaries to make
    use of Libgpg-error's system call wrapper functions.
  * Fixed bug in the locking code when used with the nPth threading
    library.
  * Added new error codes.
  * Interface changes relative to the 1.23 release:
    gpgrt_get_syscall_clamp          NEW.
    GPG_ERR_ENGINE_TOO_OLD	     NEW.
    GPG_ERR_WINDOW_TOO_SMALL         NEW.
    GPG_ERR_WINDOW_TOO_LARGE         NEW.
    GPG_ERR_MISSING_ENVVAR	     NEW.
    GPG_ERR_USER_ID_EXISTS           NEW.
    GPG_ERR_NAME_EXISTS              NEW.
    GPG_ERR_DUP_NAME                 NEW.
    GPG_ERR_TOO_OLD                  NEW.
    GPG_ERR_TOO_YOUNG                NEW.
* Mon Jul 18 2016 astieger@suse.com
- update to 1.24:
  * Fixes a bug in es_fclose_snatch when used used after es_fseek.
  * Fixes building without thread support.
  * New configure option --disable-tests.
* Wed Jun 15 2016 astieger@suse.com
- update to 1.23:
  * Fixes an assertion failure due to es_flush on read/write streams.
  * Fixes a bug with a too short memory limit is es_fopenmen.
  * Interface changes relative to the 1.22 release:
    GPG_ERR_SUBKEYS_EXP_OR_REV       NEW.
* Fri Apr 29 2016 astieger@suse.com
- update to 1.22:
  * Support for LeakSanitizer with the gpgrt_annotate_leaked_object
    inline function.
  * Interface changes relative to the 1.21 release:
    GPG_ERR_DB_CORRUPTED             NEW.
    gpgrt_annotate_leaked_object     NEW inline func.
    GPGRT_ENABLE_W32_ICONV_MACROS    NEW.
    gpgrt_w32_iconv_open             NEW.
    gpgrt_w32_iconv_close            NEW.
    gpgrt_w32_iconv                  NEW.
* Mon Dec 14 2015 astieger@suse.com
- update to 1.21:
  * New functions gpgrt_poll and gpgrt_set_nonblock.  For now only
    pipes and sockets on Unix are supported.
  * Interface changes relative to the 1.20 release:
    gpgrt_set_nonblock               NEW.
    gpgrt_get_nonblock               NEW.
    gpgrt_poll                       NEW.
    gpgrt_poll_t                     NEW type.
    es_poll_t                        NEW type.
    es_set_nonblock                  NEW macro.
    es_get_nonblock                  NEW macro.
    es_poll                          NEW macro.
    GPG_ERR_TRUE                     NEW.
    GPG_ERR_FALSE                    NEW.
    GPG_ERR_NO_NAME                  NEW.
    GPG_ERR_NO_KEY                   NEW.
    GPG_ERR_SERVER_FAILED            NEW.
* Wed Aug 26 2015 astieger@suse.com
- update to 1.20:
  * New macros for GCC attributes.
  * Allow building without thread support.
  * Build without a build timestamp by default.
  * Interface changes relative to the 1.19 release:
  GPGRT_VERSION                    NEW macro.
  GPGRT_VERSION_NUMBER             NEW macro.
  GPGRT_INLINE                     NEW macro.
  GPGRT_GCC_VERSION                NEW macro.
  GPGRT_ATTR_NORETURN              NEW macro.
  GPGRT_ATTR_PRINTF                NEW macro.
  GPGRT_ATTR_NR_PRINTF             NEW macro.
  GPGRT_ATTR_FORMAT_ARG            NEW macro.
  GPGRT_ATTR_SENTINEL              NEW macro.
  GPGRT_ATTR_USED                  NEW macro.
  GPGRT_ATTR_UNUSED                NEW macro.
  GPGRT_ATTR_DEPRECATED            NEW macro.
  GPGRT_ATTR_PURE                  NEW macro.
  GPGRT_ATTR_MALLOC                NEW macro.
  GPGRT_HAVE_MACRO_FUNCTION        NEW macro.
  GPGRT_HAVE_PRAGMA_GCC_PUSH       NEW macro.
* Fri Apr 10 2015 astieger@suse.com
- update to 1.19:
  * New set of error codes for use with LDAP.
  * New options --help and --defines for gpg-error.
  * Allow building with gcc 5.
  (replacing patch libgpg-error-1.18-gcc5.patch now removed)
  * Interface changes relative to the 1.18 release:
  GPG_ERR_LDAP_*                   NEW.
* Thu Mar 19 2015 astieger@suse.com
- remove libtool requirement
* Thu Feb 19 2015 rguenther@suse.com
- Add libgpg-error-1.18-gcc5.patch to pass -P to the preprocessor
  when generating files to deal with C preprocessor changes in GCC 4.9 and up.
* Mon Jan 26 2015 andreas.stieger@gmx.de
- update to 1.18:
  * New translations for Hungarian, Portuguese, Russian, and
  traditional Chinese.  Updated other translations.
  * New error codes.
  * Interface changes relative to the 1.17 release:
  GPG_ERR_FORBIDDEN                NEW.
  GPG_ERR_OBJ_TERM_STATE           NEW.
  GPG_ERR_REQUEST_TOO_SHORT        NEW.
  GPG_ERR_REQUEST_TOO_LONG         NEW.
  GPG_ERR_LEGACY_KEY               NEW.
* Wed Oct 15 2014 andreas.stieger@gmx.de
- update to 1.17:
  * New error codes for TLS protocol libraries.
  * New configure option --enable-build-timestamp.
  * New man page for gpg-error-config.
  * Interface changes relative to the 1.16 release:
  GPG_ERR_SOURCE_TLS               NEW.
  GPG_ERR_NO_CERT_CHAIN            NEW.
  GPG_ERR_CERT_TOO_LARGE	          NEW.
  GPG_ERR_INV_RECORD               NEW.
  GPG_ERR_BAD_MAC	          NEW.
  GPG_ERR_UNEXPECTED_MSG           NEW.
  GPG_ERR_COMPR_FAILED             NEW.
  GPG_ERR_WOULD_WRAP               NEW.
  GPG_ERR_FATAL_ALERT              NEW.
  GPG_ERR_NO_CIPHER                NEW.
  GPG_ERR_MISSING_CLIENT_CERT      NEW.
  GPG_ERR_CLOSE_NOTIFY             NEW.
  GPG_ERR_TICKET_EXPIRED           NEW.
  GPG_ERR_BAD_TICKET               NEW.
  GPG_ERR_UNKNOWN_IDENTITY         NEW.
  GPG_ERR_BAD_HS_CERT              NEW.
  GPG_ERR_BAD_HS_CERT_REQ          NEW.
  GPG_ERR_BAD_HS_CERT_VER          NEW.
  GPG_ERR_BAD_HS_CHANGE_CIPHER     NEW.
  GPG_ERR_BAD_HS_CLIENT_HELLO      NEW.
  GPG_ERR_BAD_HS_SERVER_HELLO      NEW.
  GPG_ERR_BAD_HS_SERVER_HELLO_DONE NEW.
  GPG_ERR_BAD_HS_FINISHED          NEW.
  GPG_ERR_BAD_HS_SERVER_KEX        NEW.
  GPG_ERR_BAD_HS_CLIENT_KEX        NEW.
  GPG_ERR_BOGUS_STRING             NEW.
  gpgrt_pending                    NEW.
  gpgrt_pending_unlocked           NEW.
- Build with --enable-build-timestamp=no to prevent unneccessary
  rebuilds of dependent packages
- add required spec for introducted info page
* Sun Sep 21 2014 andreas.stieger@gmx.de
- update to 1.16:
  * Fixed a prototype mismatch.
  * Fix es_fclose for streams opened with "samethread".
* Sat Sep 13 2014 meissner@suse.com
- update to 1.15:
  * This releases fixes problems with the use of off_t and ssize_t by
  the estream functions introduced with 1.14.  Although this is
  technically an ABI break on some platforms, we take this as a
  simple bug fix for 1.14.  The new functions are very unlikely in
  use by any code and thus no breakage should happen.  The 1.14
  tarball will be removed from the archive.
  * Add type gpgrt_off_t which is guaranteed to be 64 bit.
  * Add type gpgrt_ssize_t to make use on Windows easier.  On Unix
  platforms this is an alias for ssize_t.
* Wed Sep 10 2014 andreas.stieger@gmx.de
- update to 1.14:
  * Added gpgrt_lock_trylock.
  * Added the estream library under the name gpgrt and a set of macros
  to use them with their "es_" names.
  * Interface changes relative to the 1.13 release:
  GPG_ERR_KEY_DISABLED         NEW.
  gpgrt_*, GPGPT_*             NEW.
* Sun Apr 27 2014 andreas.stieger@gmx.de
- update to 1.13:
  * Added a portable mutex API.
  * The AM_PATH_GPG_ERROR macro now defines GPG_ERROR_MT_CFLAGS
    and GPG_ERROR_MT_LIBS autoconf output variables for use by
    programs which need gpgrt based thread support.
    gpg-error-config has a new option --mt.
- Interface changes relative to the 1.12 release:
  GPG_ERR_KEY_ON_CARD          NEW.
  GPG_ERR_MAC_ALGO             NEW.
  GPG_ERR_INV_LOCK_OBJ         NEW.
  gpgrt_lock_t                 NEW.
  GPGRT_LOCK_INITIALIZER       NEW.
  GPGRT_LOCK_DEFINE            NEW.
  gpgrt_lock_init              NEW.
  gpgrt_lock_lock              NEW.
  gpgrt_lock_unlock            NEW.
  gpgrt_lock_destroy           NEW.
  gpgrt_yield                  NEW.
- run available tests
- fix SLE 11 SP2 build (make install)
* Mon Aug 19 2013 andreas.stieger@gmx.de
- update to 1.12
  * Interface changes relative to the 1.11 release:
  GPG_ERR_NO_CRYPT_CTX         NEW.
  GPG_ERR_WRONG_CRYPT_CTX      NEW.
  GPG_ERR_BAD_CRYPT_CTX        NEW.
  GPG_ERR_CRYPT_CTX_CONFLICT   NEW.
  GPG_ERR_BROKEN_PUBKEY        NEW.
  GPG_ERR_BROKEN_SECKEY        NEW.
- drop unused libgpg-error-nld-build.diff
- drop autoreconv call
* Tue Jun 18 2013 coolo@suse.com
- remove gpg verification from bootstrap packages
* Mon Feb 25 2013 andreas.stieger@gmx.de
- update to 1.11
  * New error source GPG_ERR_SOURCE_ASSUAN for Libassuan related
  errors.
  * New macros GPG_ERROR_VERSION and GPG_ERROR_VERSION_NUMBER.  New
  function gpg_error_check_version.
  * Interface changes relative to the 1.10 release:
  GPG_ERR_NO_KEYSERVER          NEW.
  GPG_ERR_INV_CURVE             NEW.
  GPG_ERR_UNKNOWN_CURVE         NEW.
  GPG_ERR_DUP_KEY               NEW.
  GPG_ERR_AMBIGUOUS             NEW.
  GPG_ERR_SOURCE_ASSUAN         NEW.
  gpg_error_check_version       NEW.
  GPG_ERROR_VERSION             NEW.
  GPG_ERROR_VERSION_NUMBER      NEW.
- add offline verification of source signature
* Sat Feb  2 2013 coolo@suse.com
- update license to new format
* Sun Feb 12 2012 crrodriguez@opensuse.org
- Move libraries back to %%{_libdir}, /usr merge project
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct  2 2011 crrodriguez@opensuse.org
-  Update to version 1.10
  * Define GPG_ERR_ENABLE_ERRNO_MACROS.
  * Add GPG_ERR_NOT_INITIALIZED.
  * Add GPG_ERR_MISSING_ISSUER_CERT
* Fri Dec  3 2010 puzel@novell.com
- update to version 1.9
  * New function gpg_err_deinit.
  * Interface changes relative to the 1.8 release:
  GPG_ERR_MISSING_KEY           NEW
  GPG_ERR_TOO_MANY              NEW
  GPG_ERR_LIMIT_REACHED         NEW
  gpg_err_deinit                NEW
- clean up specfile
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Aug 17 2010 puzel@novell.com
- update to version 1.8
  * New option --list for gpg-error.
  * Interface changes relative to the 1.7 release:
  GPG_ERR_NOT_ENABLED           NEW
  GPG_ERR_SOURCE_G13            NEW
  GPG_ERR_NO_ENGINE             NEW
  gpg_err_set_errno             NEW
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Jun  1 2009 puzel@suse.cz
- update to version 1.7
  * Minor fixes and a few new error codes.
  * Interface changes relative to the 1.6 release:
  GPG_ERR_NOT_OPERATIONAL       NEW
  GPG_ERR_NO_PASSPHRASE         NEW
  GPG_ERR_NO_PIN                NEW
* Fri Feb 20 2009 crrodriguez@suse.de
- remove static libraries, there is no reason to use them as
  shared libraries live in /%%{_lib}
* Thu Jan 29 2009 olh@suse.de
- obsolete libgpg-error-XXbit in the library subpackage
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Nov 21 2007 mkoenig@suse.de
- update to version 1.6
  * Minor build system fixes
  * gpg-error has a new option --version
  * Interface changes relative to the 1.4 release:
    GPG_ERR_UNFINISHED            NEW
    GPG_ERR_SOURCE_GPA            NEW
    GPG_ERR_SOURCE_KLEO           NEW
- package branch to conform shlib policy:
  libgpg-error0
* Wed Dec 13 2006 mkoenig@suse.de
- get rid of .la file and fix devel so link
* Tue Dec  5 2006 mkoenig@suse.de
- move shared lib to /%%_lib
* Tue Sep 19 2006 mkoenig@suse.de
- update to version 1.4:
  * New error codes for the Assuan IPC library.
  * New error code GPG_ERR_MISSING_ERRNO
  * New error source GPG_ERR_SOURCE_ANY
  * New convenience functions gpg_err_code_from_syserror and
  gpg_error_from_syserror
* Thu Jul 13 2006 mskibbe@suse.de
- add autoreconf --force ( includes the missing -fPIC option while
  build )
* Wed Jul 12 2006 mskibbe@suse.de
- update to version 1.3 which
  o includes fixes in Makefiles
  o fix cast problems
  o include utf8 functions
  o add some languages
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jun 23 2005 hvogel@suse.de
- require libgpg-error
- add %%clean section
* Thu Oct 14 2004 hvogel@suse.de
- update to version 1.0
* Mon Sep 27 2004 hvogel@suse.de
- fixed ac-quotation of gpg-error.m4
* Mon Jul 19 2004 hvogel@suse.de
- correct nld_build if statement
* Wed Jul 14 2004 adrian@suse.de
- create -devel subpackage
- prepare for NLD
* Mon May 24 2004 ro@suse.de
- added return value to non-void function (main)
* Wed May 19 2004 hvogel@suse.de
- update to version 0.7
* Tue Feb 17 2004 hvogel@suse.de
- initial package, version 0.6
